@@ -91,6 +91,9 @@ dcem_cluster_uv <-
     tolerance <- .Machine$double.eps
     init_attempt = 1
 
+    # Declare a datadrame to store the data membership values.
+    membership = data.frame()
+
     # Checking for empty partitions
     # and re-attempt initialization.
     while(init_attempt < 5){
@@ -157,12 +160,16 @@ dcem_cluster_uv <-
       counter = counter + 1
     }
 
+    # Assign clusters to data
+    membership = rbind(membership, apply(weights, 2, which.max))
+    colnames(membership) <- seq(1:num_data)
+
     # Prepare output list
     output = list('prob' = weights,
                   'meu' = as.vector(meu),
                   'sigma' = sigma,
                   'prior' = prior,
-                  'membership' = apply(weights, 2, which.max)
+                  'membership' = membership
                   )
     return(output)
 
