@@ -46,8 +46,9 @@
 #'         \item (4) Priors: \strong{sample_out$prior}
 #'         A vector of priors.
 #'
-#'         \item (5) Membership: \strong{sample_out$membership}
-#'         A vector of cluster membership for data.
+#'        \item (5) Membership: \strong{sample_out$membership}: A dataframe of
+#'         cluster membership for data. Columns numbers are data indices and values
+#'         are the assigned clusters.
 #'         }
 #'
 #' @usage
@@ -113,7 +114,7 @@ dcem_star_train <-
       print(paste("Specified number of  clusters = ", num_clusters))
     }
 
-    if (missing(seeding) ) {
+    if (missing(seeding) || seeding == "rand") {
       seeding = "rand"
       print("Using the random initialisation scheme.")
     }
